@@ -36,6 +36,7 @@ Fail = None
 Success = None
 Prepare = None
 Info = None
+OutSide = None
 Debug = None
 Again = None
 ErrorIDPW = None
@@ -70,6 +71,7 @@ InputNewPassword = None
 CheckNewPassword = None
 Board = None
 IntoBoard = None
+ReadingBoardInfo = None
 BothInput = None
 NoInput = None
 CatchPost = None
@@ -187,6 +189,7 @@ NoSearchResult = None
 SkipRegistrationForm = None
 url = None
 OnlySecureConnection = None
+CatchBottomPostSuccess = None
 
 
 def specific_load(input_language, lang_list):
@@ -326,6 +329,12 @@ def load(input_lang):
         'INFO',
     ])
 
+    global OutSide
+    OutSide = specific_load(input_lang, [
+        '外部',
+        'OUTS',
+    ])
+
     global Debug
     Debug = specific_load(input_lang, [
         '除錯',
@@ -1238,6 +1247,12 @@ def load(input_lang):
         'Secure connections only',
     ])
 
+    global CatchBottomPostSuccess
+    CatchBottomPostSuccess = specific_load(input_lang, [
+        '取得置底文章成功',
+        'Catch bottom post success',
+    ])
+
     # No changes have been made to any settings
 
     # Quote original
